ProfileInterface
================

.. contents::

.. automodule:: pyhafas.profile.interfaces
   :members:
   :undoc-members:
   :show-inheritance:

Helper
------
format_products_filter
^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: pyhafas.profile.interfaces.helper.format_products_filter
   :members:
   :undoc-members:
   :show-inheritance:

date_time
^^^^^^^^^^^^^^^
.. automodule:: pyhafas.profile.interfaces.helper.date_time
   :members:
   :undoc-members:
   :show-inheritance:

parse_leg
^^^^^^^^^
.. automodule:: pyhafas.profile.interfaces.helper.parse_leg
   :members:
   :undoc-members:
   :show-inheritance:

parse_lid
^^^^^^^^^
.. automodule:: pyhafas.profile.interfaces.helper.parse_lid
   :members:
   :undoc-members:
   :show-inheritance:

request
^^^^^^^^^
.. automodule:: pyhafas.profile.interfaces.helper.request
   :members:
   :undoc-members:
   :show-inheritance:

Mappings
--------

error_codes
^^^^^^^^^^^
.. automodule:: pyhafas.profile.interfaces.mappings.error_codes
   :members:
   :undoc-members:
   :show-inheritance:

Requests
--------

journey
^^^^^^^
.. automodule:: pyhafas.profile.interfaces.requests.journey
   :members:
   :undoc-members:
   :show-inheritance:

journeys
^^^^^^^^
.. automodule:: pyhafas.profile.interfaces.requests.journeys
   :members:
   :undoc-members:
   :show-inheritance:

location
^^^^^^^^
.. automodule:: pyhafas.profile.interfaces.requests.location
   :members:
   :undoc-members:
   :show-inheritance:

station_board
^^^^^^^^^^^^^
.. automodule:: pyhafas.profile.interfaces.requests.station_board
   :members:
   :undoc-members:
   :show-inheritance:

trip
^^^^
.. automodule:: pyhafas.profile.interfaces.requests.trip
   :members:
   :undoc-members:
   :show-inheritance:
